ImageToImageInput

Struct ImageToImageInput 

pub struct ImageToImageInput {
    pub enable_safety_checker: Option<bool>,
    pub guidance_scale: Option<f64>,
    pub image_size: Option<ImageSizeProperty>,
    pub image_url: String,
    pub negative_prompt: Option<String>,
    pub num_images: Option<i64>,
    pub num_inference_steps: Option<i64>,
    pub prompt: String,
    pub prompt_expansion: Option<bool>,
    pub seed: Option<i64>,
    pub strength: Option<f64>,
    pub sync_mode: Option<bool>,
}
Available on (crate features endpoints or endpoints_fal-ai or endpoints_fal-ai_sync-lipsync or endpoints_fal-ai_veo2 or endpoints_fal-ai_minimax-music or endpoints_fal-ai_diffrhythm or endpoints_fal-ai_yue or endpoints_fal-ai_flux-pro or endpoints_fal-ai_ideogram or endpoints_fal-ai_hunyuan-video-lora-training or endpoints_fal-ai_flux-lora-fast-training or endpoints_fal-ai_flux-lora-portrait-trainer or endpoints_fal-ai_flux-pro-trainer or endpoints_fal-ai_recraft-v3 or endpoints_fal-ai_minimax or endpoints_fal-ai_minimax-image or endpoints_fal-ai_hyper3d or endpoints_fal-ai_aura-flow or endpoints_fal-ai_flux or endpoints_fal-ai_flux-lora or endpoints_fal-ai_flux-subject or endpoints_fal-ai_flux-lora-canny or endpoints_fal-ai_flux-lora-depth or endpoints_fal-ai_sana or endpoints_fal-ai_omnigen-v1 or endpoints_fal-ai_lumina-image or endpoints_fal-ai_stable-diffusion-v35-large or endpoints_fal-ai_stable-diffusion-v35-medium or endpoints_fal-ai_switti or endpoints_fal-ai_recraft-20b or endpoints_fal-ai_bria or endpoints_fal-ai_flux-lora-fill or endpoints_fal-ai_flux-control-lora-canny or endpoints_fal-ai_flux-control-lora-depth or endpoints_fal-ai_flux-general or endpoints_fal-ai_flux-pulid or endpoints_fal-ai_iclight-v2 or endpoints_fal-ai_flux-differential-diffusion or endpoints_fal-ai_stable-diffusion-v3-medium or endpoints_fal-ai_fast-sdxl or endpoints_fal-ai_lora or endpoints_fal-ai_aura-sr or endpoints_fal-ai_codeformer or endpoints_fal-ai_thera or endpoints_fal-ai_ddcolor or endpoints_fal-ai_swin2sr or endpoints_fal-ai_mix-dehaze-net or endpoints_fal-ai_docres or endpoints_fal-ai_nafnet or endpoints_fal-ai_drct-super-resolution or endpoints_fal-ai_ben or endpoints_fal-ai_flowedit or endpoints_fal-ai_zonos or endpoints_fal-ai_stable-cascade or endpoints_fal-ai_mochi-v1 or endpoints_fal-ai_stepfun-video or endpoints_fal-ai_hunyuan-video or endpoints_fal-ai_hunyuan-video-image-to-video or endpoints_fal-ai_hunyuan-video-img2vid-lora or endpoints_fal-ai_hunyuan-video-lora or endpoints_fal-ai_wan or endpoints_fal-ai_wan-t2v or endpoints_fal-ai_wan-i2v or endpoints_fal-ai_wan-i2v-lora or endpoints_fal-ai_wan-trainer or endpoints_fal-ai_wan-pro or endpoints_fal-ai_wan-effects or endpoints_fal-ai_skyreels-i2v or endpoints_fal-ai_vidu or endpoints_fal-ai_video-upscaler or endpoints_fal-ai_auto-caption or endpoints_fal-ai_mmaudio-v2 or endpoints_fal-ai_luma-dream-machine or endpoints_fal-ai_luma-photon or endpoints_fal-ai_kling or endpoints_fal-ai_kling-video or endpoints_fal-ai_pixverse or endpoints_fal-ai_transpixar or endpoints_fal-ai_cogvideox-5b or endpoints_fal-ai_cogview4 or endpoints_fal-ai_ltx-video or endpoints_fal-ai_ltx-video-v095 or endpoints_fal-ai_stable-video or endpoints_fal-ai_fast-svd or endpoints_fal-ai_fast-svd-lcm or endpoints_fal-ai_birefnet or endpoints_fal-ai_got-ocr or endpoints_fal-ai_creative-upscaler or endpoints_fal-ai_ffmpeg-api or endpoints_fal-ai_clarity-upscaler or endpoints_fal-ai_ccsr or endpoints_fal-ai_fast-turbo-diffusion or endpoints_fal-ai_fast-lcm-diffusion or endpoints_fal-ai_whisper or endpoints_fal-ai_wizper or endpoints_fal-ai_fast-lightning-sdxl or endpoints_fal-ai_hyper-sdxl or endpoints_fal-ai_playground-v25 or endpoints_fal-ai_amt-interpolation or endpoints_fal-ai_t2v-turbo or endpoints_fal-ai_sd15-depth-controlnet or endpoints_fal-ai_photomaker or endpoints_fal-ai_lcm or endpoints_fal-ai_lcm-sd15-i2i or endpoints_fal-ai_fooocus or endpoints_fal-ai_animatediff-v2v or endpoints_fal-ai_fast-animatediff or endpoints_fal-ai_illusion-diffusion or endpoints_fal-ai_imageutils or endpoints_fal-ai_esrgan or endpoints_fal-ai_fast-sdxl-controlnet-canny or endpoints_fal-ai_inpaint or endpoints_fal-ai_animatediff-sparsectrl-lcm or endpoints_fal-ai_pulid or endpoints_fal-ai_ip-adapter-face-id or endpoints_fal-ai_stable-audio or endpoints_fal-ai_diffusion-edge or endpoints_fal-ai_triposr or endpoints_fal-ai_retoucher or endpoints_fal-ai_any-llm or endpoints_fal-ai_llavav15-13b or endpoints_fal-ai_llava-next or endpoints_fal-ai_fast-fooocus-sdxl or endpoints_fal-ai_face-to-sticker or endpoints_fal-ai_moondream or endpoints_fal-ai_sadtalker or endpoints_fal-ai_musetalk or endpoints_fal-ai_dubbing or endpoints_fal-ai_layer-diffusion or endpoints_fal-ai_stable-diffusion-v15 or endpoints_fal-ai_pixart-sigma or endpoints_fal-ai_dreamshaper or endpoints_fal-ai_realistic-vision or endpoints_fal-ai_lightning-models or endpoints_fal-ai_omni-zero or endpoints_fal-ai_leffa or endpoints_fal-ai_cat-vton or endpoints_fal-ai_dwpose or endpoints_fal-ai_florence-2-large or endpoints_fal-ai_era-3d or endpoints_fal-ai_live-portrait or endpoints_fal-ai_kolors or endpoints_fal-ai_sdxl-controlnet-union or endpoints_fal-ai_sam2 or endpoints_fal-ai_evf-sam or endpoints_fal-ai_sa2va or endpoints_fal-ai_mini-cpm or endpoints_fal-ai_controlnext or endpoints_fal-ai_workflowutils or endpoints_fal-ai_image-preprocessors or endpoints_fal-ai_f5-tts or endpoints_fal-ai_kokoro or endpoints_fal-ai_trellis or endpoints_fal-ai_hunyuan3d or endpoints_fal-ai_playai or endpoints_fal-ai_latentsync or endpoints_fal-ai_moondream-next or endpoints_fal-ai_recraft-clarity-upscale or endpoints_fal-ai_recraft-creative-upscale or endpoints_fal-ai_elevenlabs or endpoints_fal-ai_janus or endpoints_fal-ai_imagen3 or endpoints_fal-ai_gemini-flash-edit or endpoints_fal-ai_post-processing or endpoints_fal-ai_video-prompt-generator or endpoints_fal-ai_eye-correct or endpoints_fal-ai_topaz or endpoints_fal-ai_csm-1b or endpoints_fal-ai_pika or endpoints_fal-ai_invisible-watermark) and (crate features endpoints or endpoints_fal-ai or endpoints_fal-ai_stable-diffusion-v3-medium) only.

Fields

enable_safety_checker: Option<bool>

If set to true, the safety checker will be enabled.

guidance_scale: Option<f64>

The CFG (Classifier Free Guidance) scale is a measure of how close you want the model to stick to your prompt when looking for a related image to show you.

image_size: Option<ImageSizeProperty>

The size of the generated image. Defaults to the conditioning image’s size. null

image_url: String

The image URL to generate an image from. “https://fal.media/files/zebra/b52cVi3BhLDJcBrk6x0DL.png”

negative_prompt: Option<String>

The negative prompt to generate an image from.

num_images: Option<i64>

The number of images to generate.

num_inference_steps: Option<i64>

The number of inference steps to perform.

prompt: String

The prompt to generate an image from. “cat wizard, gandalf, lord of the rings, detailed, fantasy, cute, adorable, Pixar, Disney, 8k”

prompt_expansion: Option<bool>

If set to true, prompt will be upsampled with more details.

seed: Option<i64>

The same seed and the same prompt given to the same version of Stable Diffusion will output the same image every time.

strength: Option<f64>

The strength of the image-to-image transformation.

sync_mode: Option<bool>

If set to true, the function will wait for the image to be generated and uploaded before returning the response. This will increase the latency of the function but it allows you to get the image directly in the response without going through the CDN.