pub struct Era3DInput {
pub background_removal: Option<bool>,
pub cfg: Option<f64>,
pub crop_size: Option<i64>,
pub image_url: String,
pub seed: Option<i64>,
pub steps: Option<i64>,
}Fields
background_removal: Option<bool>Background removal
cfg: Option<f64>The CFG (Classifier Free Guidance) scale is a measure of how close you want the model to stick to your prompt when looking for a related image to show you.
crop_size: Option<i64>Size of the image to crop to
image_url: StringURL of the image to remove background from/// URL of the image to remove background from/// “https://storage.googleapis.com/falserverless/model_tests/era3d/DnvGjd9CCS-ESmLgTYgOn.png”
seed: Option<i64>Seed for random number generation
steps: Option<i64>Number of steps to run the model for