pub struct HunyuanT2VRequest {
pub aspect_ratio: Option<String>,
pub enable_safety_checker: Option<bool>,
pub loras: Option<Vec<Option<LoraWeight>>>,
pub num_frames: Option<String>,
pub pro_mode: Option<bool>,
pub prompt: String,
pub resolution: Option<String>,
pub seed: Option<i64>,
}Fields
aspect_ratio: Option<String>The aspect ratio of the video to generate.
enable_safety_checker: Option<bool>If set to true, the safety checker will be enabled./// If set to true, the safety checker will be enabled./// true
loras: Option<Vec<Option<LoraWeight>>>The LoRAs to use for the image generation. You can use any number of LoRAs and they will be merged together to generate the final image./// The LoRAs to use for the image generation. You can use any number of LoRAs and they will be merged together to generate the final image.
num_frames: Option<String>The number of frames to generate.
pro_mode: Option<bool>By default, generations are done with 35 steps. Pro mode does 55 steps which results in higher quality videos but will take more time and cost 2x more billing units.
prompt: StringThe prompt to generate the video from./// The prompt to generate the video from./// “A stylish woman walks down a Tokyo street filled with warm glowing neon and animated city signage. She wears a black leather jacket, a long red dress, and black boots, and carries a black purse.”
resolution: Option<String>The resolution of the video to generate.
seed: Option<i64>The seed to use for generating the video.