pub struct IllusionDiffusionOutput {
pub image: Image,
pub seed: i64,
}Fields
image: ImageThe generated image file info.
seed: i64Seed of the generated Image. It will be the same value of the one passed in the input or the randomly generated that was used in case none was passed.