pub struct InpaintInput {
pub guidance_scale: Option<f64>,
pub image_url: String,
pub mask_url: String,
pub model_name: String,
pub negative_prompt: Option<String>,
pub num_inference_steps: Option<i64>,
pub prompt: String,
pub seed: Option<i64>,
}Fields
guidance_scale: Option<f64>The CFG (Classifier Free Guidance) scale is a measure of how close you want the model to stick to your prompt when looking for a related image to show you.
image_url: StringInput image for img2img or inpaint mode/// Input image for img2img or inpaint mode/// “https://raw.githubusercontent.com/CompVis/latent-diffusion/main/data/inpainting_examples/overture-creations-5sI6fQgYIuo.png”
mask_url: StringInput mask for inpaint mode. Black areas will be preserved, white areas will be inpainted./// Input mask for inpaint mode. Black areas will be preserved, white areas will be inpainted./// “https://raw.githubusercontent.com/CompVis/latent-diffusion/main/data/inpainting_examples/overture-creations-5sI6fQgYIuo_mask.png”
model_name: StringURL or HuggingFace ID of the base model to generate the image./// URL or HuggingFace ID of the base model to generate the image./// “diffusers/stable-diffusion-xl-1.0-inpainting-0.1” “stabilityai/stable-diffusion-xl-base-1.0” “runwayml/stable-diffusion-v1-5” “SG161222/Realistic_Vision_V2.0”
negative_prompt: Option<String>The negative prompt to use. Use it to address details that you don’t want in the image. This could be colors, objects, scenery and even the small details (e.g. moustache, blurry, low resolution)./// The negative prompt to use. Use it to address details that you don’t want in the image. This could be colors, objects, scenery and even the small details (e.g. moustache, blurry, low resolution)./// “cartoon, painting, illustration, (worst quality, low quality, normal quality:2)” “nsfw, cartoon, (epicnegative:0.9)”
num_inference_steps: Option<i64>Increasing the amount of steps tells Stable Diffusion that it should take more steps to generate your final result which can increase the amount of detail in your image.
prompt: StringThe prompt to use for generating the image. Be as descriptive as possible for best results./// The prompt to use for generating the image. Be as descriptive as possible for best results./// “a photo of a cat”
seed: Option<i64>The same seed and the same prompt given to the same version of Stable Diffusion will output the same image every time./// The same seed and the same prompt given to the same version of Stable Diffusion will output the same image every time./// 1234