pub struct PiDiInput {
pub apply_filter: Option<bool>,
pub image_url: String,
pub safe: Option<bool>,
pub scribble: Option<bool>,
}Fields
apply_filter: Option<bool>Whether to apply the filter to the image.
image_url: StringURL of the image to process/// URL of the image to process/// “https://storage.googleapis.com/falserverless/model_tests/image_preprocessors/cat.png”
safe: Option<bool>Whether to use the safe version of the Pidi detector
scribble: Option<bool>Whether to use the scribble version of the Pidi detector