Struct RealisticVisionTextToImageInput

pub struct RealisticVisionTextToImageInput {
Show 15 fields pub embeddings: Option<Vec<Option<Embedding>>>, pub enable_safety_checker: Option<bool>, pub expand_prompt: Option<bool>, pub format: Option<String>, pub guidance_scale: Option<f64>, pub image_size: Option<ImageSizeProperty>, pub loras: Option<Vec<Option<LoraWeight>>>, pub model_name: Option<String>, pub negative_prompt: Option<String>, pub num_images: Option<i64>, pub num_inference_steps: Option<i64>, pub prompt: String, pub safety_checker_version: Option<String>, pub seed: Option<i64>, pub sync_mode: Option<bool>,
}

Fields

embeddings: Option<Vec<Option<Embedding>>>

The list of embeddings to use.

enable_safety_checker: Option<bool>

If set to true, the safety checker will be enabled.

expand_prompt: Option<bool>

If set to true, the prompt will be expanded with additional prompts.

format: Option<String>

The format of the generated image.

guidance_scale: Option<f64>

The CFG (Classifier Free Guidance) scale is a measure of how close you want the model to stick to your prompt when looking for a related image to show you.

image_size: Option<ImageSizeProperty>loras: Option<Vec<Option<LoraWeight>>>

The list of LoRA weights to use.

model_name: Option<String>

The Realistic Vision model to use./// The Realistic Vision model to use./// “SG161222/Realistic_Vision_V6.0_B1_noVAE” “SG161222/RealVisXL_V4.0”

negative_prompt: Option<String>

The negative prompt to use. Use it to address details that you don’t want in the image.

num_images: Option<i64>

The number of images to generate.

num_inference_steps: Option<i64>

The number of inference steps to perform.

prompt: String

The prompt to use for generating the image. Be as descriptive as possible for best results./// The prompt to use for generating the image. Be as descriptive as possible for best results./// “A hyperdetailed photograph of a Cat dressed as a mafia boss holding a fish walking down a Japanese fish market with an angry face, 8k resolution, best quality, beautiful photograph, dynamic lighting,”

safety_checker_version: Option<String>

The version of the safety checker to use. v1 is the default CompVis safety checker. v2 uses a custom ViT model.

seed: Option<i64>

The same seed and the same prompt given to the same version of Stable Diffusion will output the same image every time.

sync_mode: Option<bool>

If set to true, the function will wait for the image to be generated and uploaded before returning the response. This will increase the latency of the function but it allows you to get the image directly in the response without going through the CDN.