pub struct SchnellTextToImageInput {
pub enable_safety_checker: Option<bool>,
pub image_size: Option<ImageSizeProperty>,
pub num_images: Option<i64>,
pub num_inference_steps: Option<i64>,
pub prompt: String,
pub seed: Option<i64>,
pub sync_mode: Option<bool>,
}Fields
enable_safety_checker: Option<bool>If set to true, the safety checker will be enabled.
image_size: Option<ImageSizeProperty>The size of the generated image.
num_images: Option<i64>The number of images to generate.
num_inference_steps: Option<i64>The number of inference steps to perform.
prompt: StringThe prompt to generate an image from./// The prompt to generate an image from./// “Extreme close-up of a single tiger eye, direct frontal view. Detailed iris and pupil. Sharp focus on eye texture and color. Natural lighting to capture authentic eye shine and depth. The word "FLUX" is painted over it in big, white brush strokes with visible texture.”
seed: Option<i64>The same seed and the same prompt given to the same version of the model will output the same image every time.
sync_mode: Option<bool>If set to true, the function will wait for the image to be generated and uploaded before returning the response. This will increase the latency of the function but it allows you to get the image directly in the response without going through the CDN.