Struct V3TTSInput

pub struct V3TTSInput {
    pub input: String,
    pub response_format: Option<String>,
    pub seed: Option<i64>,
    pub voice: String,
}

Fields

input: String

The text to be converted to speech./// The text to be converted to speech./// “The quick brown fox jumped over the lazy dog.”

response_format: Option<String>

The format of the response.

seed: Option<i64>

An integer number greater than or equal to 0. If equal to null or not provided, a random seed will be used. Useful to control the reproducibility of the generated audio. Assuming all other properties didn’t change, a fixed seed should always generate the exact same audio file./// An integer number greater than or equal to 0. If equal to null or not provided, a random seed will be used. Useful to control the reproducibility of the generated audio. Assuming all other properties didn’t change, a fixed seed should always generate the exact same audio file./// null

voice: String

The unique ID of a PlayHT or Cloned Voice, or a name from the available presets./// The unique ID of a PlayHT or Cloned Voice, or a name from the available presets./// “Jennifer (English (US)/American)” “Dexter (English (US)/American)” “Ava (English (AU)/Australian)” “Tilly (English (AU)/Australian)” “Charlotte (Advertising) (English (CA)/Canadian)” “Charlotte (Meditation) (English (CA)/Canadian)” “Cecil (English (GB)/British)” “Sterling (English (GB)/British)” “Cillian (English (IE)/Irish)” “Madison (English (IE)/Irish)” “Ada (English (ZA)/South african)” “Furio (English (IT)/Italian)” “Alessandro (English (IT)/Italian)” “Carmen (English (MX)/Mexican)” “Sumita (English (IN)/Indian)” “Navya (English (IN)/Indian)” “Baptiste (English (FR)/French)” “Lumi (English (FI)/Finnish)” “Ronel Conversational (Afrikaans/South african)” “Ronel Narrative (Afrikaans/South african)” “Abdo Conversational (Arabic/Arabic)” “Abdo Narrative (Arabic/Arabic)” “Mousmi Conversational (Bengali/Bengali)” “Mousmi Narrative (Bengali/Bengali)” “Caroline Conversational (Portuguese (BR)/Brazilian)” “Caroline Narrative (Portuguese (BR)/Brazilian)” “Ange Conversational (French/French)” “Ange Narrative (French/French)” “Anke Conversational (German/German)” “Anke Narrative (German/German)” “Bora Conversational (Greek/Greek)” “Bora Narrative (Greek/Greek)” “Anuj Conversational (Hindi/Indian)” “Anuj Narrative (Hindi/Indian)” “Alessandro Conversational (Italian/Italian)” “Alessandro Narrative (Italian/Italian)” “Kiriko Conversational (Japanese/Japanese)” “Kiriko Narrative (Japanese/Japanese)” “Dohee Conversational (Korean/Korean)” “Dohee Narrative (Korean/Korean)” “Ignatius Conversational (Malay/Malay)” “Ignatius Narrative (Malay/Malay)” “Adam Conversational (Polish/Polish)” “Adam Narrative (Polish/Polish)” “Andrei Conversational (Russian/Russian)” “Andrei Narrative (Russian/Russian)” “Aleksa Conversational (Serbian/Serbian)” “Aleksa Narrative (Serbian/Serbian)” “Carmen Conversational (Spanish/Spanish)” “Patricia Conversational (Spanish/Spanish)” “Aiken Conversational (Tagalog/Filipino)” “Aiken Narrative (Tagalog/Filipino)” “Katbundit Conversational (Thai/Thai)” “Katbundit Narrative (Thai/Thai)” “Ali Conversational (Turkish/Turkish)” “Ali Narrative (Turkish/Turkish)” “Sahil Conversational (Urdu/Pakistani)” “Sahil Narrative (Urdu/Pakistani)” “Mary Conversational (Hebrew/Israeli)” “Mary Narrative (Hebrew/Israeli)”