pub struct VideoEffectsRequest {
pub duration: Option<String>,
pub effect_scene: String,
pub input_image_urls: Option<Vec<Option<String>>>,
}Fields
duration: Option<String>The duration of the generated video in seconds
effect_scene: StringThe effect scene to use for the video generation/// The effect scene to use for the video generation/// “hug”
input_image_urls: Option<Vec<Option<String>>>URL of images./// URL of images./// [“https://storage.googleapis.com/falserverless/juggernaut_examples/VHXMavzPyI27zi6JseyL4.png”,“https://storage.googleapis.com/falserverless/juggernaut_examples/QEW5VrzccxGva7mPfEXjf.png”]