pub struct VideoToVideoInput {
pub export_fps: Option<i64>,
pub guidance_scale: Option<f64>,
pub loras: Option<Vec<Option<LoraWeight>>>,
pub negative_prompt: Option<String>,
pub num_inference_steps: Option<i64>,
pub prompt: String,
pub seed: Option<i64>,
pub strength: Option<f64>,
pub use_rife: Option<bool>,
pub video_size: Option<VideoSizeProperty>,
pub video_url: String,
}Fields
export_fps: Option<i64>The target FPS of the video
guidance_scale: Option<f64>The CFG (Classifier Free Guidance) scale is a measure of how close you want the model to stick to your prompt when looking for a related video to show you.
loras: Option<Vec<Option<LoraWeight>>>The LoRAs to use for the image generation. We currently support one lora./// The LoRAs to use for the image generation. We currently support one lora.
negative_prompt: Option<String>The negative prompt to generate video from/// The negative prompt to generate video from/// “Distorted, discontinuous, Ugly, blurry, low resolution, motionless, static, disfigured, disconnected limbs, Ugly faces, incomplete arms”
num_inference_steps: Option<i64>The number of inference steps to perform.
prompt: StringThe prompt to generate the video from./// The prompt to generate the video from./// “An astronaut stands triumphantly at the peak of a towering mountain. Panorama of rugged peaks and valleys. Very futuristic vibe and animated aesthetic. Highlights of purple and golden colors in the scene. The sky is looks like an animated/cartoonish dream of galaxies, nebulae, stars, planets, moons, but the remainder of the scene is mostly realistic. “
seed: Option<i64>The same seed and the same prompt given to the same version of the model will output the same video every time.
strength: Option<f64>The strength to use for Video to Video. 1.0 completely remakes the video while 0.0 preserves the original.
use_rife: Option<bool>Use RIFE for video interpolation
video_size: Option<VideoSizeProperty>The size of the generated video.
video_url: StringThe video to generate the video from./// The video to generate the video from./// “https://huggingface.co/datasets/huggingface/documentation-images/resolve/main/diffusers/hiker.mp4”