Struct WanI2VRequest

pub struct WanI2VRequest {
    pub enable_prompt_expansion: Option<bool>,
    pub enable_safety_checker: Option<bool>,
    pub frames_per_second: Option<i64>,
    pub image_url: String,
    pub num_frames: Option<i64>,
    pub num_inference_steps: Option<i64>,
    pub prompt: String,
    pub resolution: Option<String>,
    pub seed: Option<i64>,
}

Fields

enable_prompt_expansion: Option<bool>

Whether to enable prompt expansion./// Whether to enable prompt expansion./// true

enable_safety_checker: Option<bool>

If set to true, the safety checker will be enabled./// If set to true, the safety checker will be enabled./// true

frames_per_second: Option<i64>

Frames per second of the generated video. Must be between 5 to 24.

image_url: String

URL of the input image./// URL of the input image./// “https://fal.media/files/elephant/8kkhB12hEZI2kkbU8pZPA_test.jpeg”

num_frames: Option<i64>

Number of frames to generate. Must be between 81 to 100 (inclusive).

num_inference_steps: Option<i64>

Number of inference steps for sampling. Higher values give better quality but take longer.

prompt: String

The text prompt to guide video generation./// The text prompt to guide video generation./// “A stylish woman walks down a Tokyo street filled with warm glowing neon and animated city signage.”

resolution: Option<String>

Resolution of the generated video (480p or 720p).

seed: Option<i64>

Random seed for reproducibility. If None, a random seed is chosen.