pub struct CATVTONInput {
pub cloth_type: String,
pub garment_image_url: String,
pub guidance_scale: Option<f64>,
pub human_image_url: String,
pub image_size: Option<ImageSizeProperty>,
pub num_inference_steps: Option<i64>,
pub seed: Option<i64>,
}Fields
cloth_type: StringType of the Cloth to be tried on.
Options: upper: Upper body cloth lower: Lower body cloth overall: Full body cloth inner: Inner cloth, like T-shirt inside a jacket outer: Outer cloth, like a jacket over a T-shirt/// Type of the Cloth to be tried on.
Options: upper: Upper body cloth lower: Lower body cloth overall: Full body cloth inner: Inner cloth, like T-shirt inside a jacket outer: Outer cloth, like a jacket over a T-shirt/// “upper” “lower” “overall” “inner” “outer”
garment_image_url: StringUrl to the garment image./// Url to the garment image./// “https://storage.googleapis.com/falserverless/catvton/tshirt.jpg”
guidance_scale: Option<f64>The CFG (Classifier Free Guidance) scale is a measure of how close you want the model to stick to your prompt when looking for a related image to show you.
human_image_url: StringUrl for the human image./// Url for the human image./// “https://storage.googleapis.com/falserverless/catvton/man5.jpg”
image_size: Option<ImageSizeProperty>The size of the generated image.
num_inference_steps: Option<i64>The number of inference steps to perform.
seed: Option<i64>The same seed and the same input given to the same version of the model will output the same image every time.