pub struct DevReduxInput {
pub enable_safety_checker: Option<bool>,
pub guidance_scale: Option<f64>,
pub image_size: Option<ImageSizeProperty>,
pub image_url: String,
pub num_images: Option<i64>,
pub num_inference_steps: Option<i64>,
pub seed: Option<i64>,
pub sync_mode: Option<bool>,
}Fields
enable_safety_checker: Option<bool>If set to true, the safety checker will be enabled.
guidance_scale: Option<f64>The CFG (Classifier Free Guidance) scale is a measure of how close you want the model to stick to your prompt when looking for a related image to show you.
image_size: Option<ImageSizeProperty>The size of the generated image.
image_url: StringThe URL of the image to generate an image from./// The URL of the image to generate an image from./// “https://fal.media/files/kangaroo/acQvq-Kmo2lajkgvcEHdv.png”
num_images: Option<i64>The number of images to generate.
num_inference_steps: Option<i64>The number of inference steps to perform.
seed: Option<i64>The same seed and the same prompt given to the same version of the model will output the same image every time.
sync_mode: Option<bool>If set to true, the function will wait for the image to be generated and uploaded before returning the response. This will increase the latency of the function but it allows you to get the image directly in the response without going through the CDN.