pub struct EraserInput {
pub image_url: String,
pub mask_type: Option<String>,
pub mask_url: String,
pub preserve_alpha: Option<bool>,
pub sync_mode: Option<bool>,
}Fields
image_url: StringInput Image to erase from/// Input Image to erase from/// “https://storage.googleapis.com/falserverless/bria/bria_eraser_img.png”
mask_type: Option<String>You can use this parameter to specify the type of the input mask from the list. ‘manual’ opttion should be used in cases in which the mask had been generated by a user (e.g. with a brush tool), and ‘automatic’ mask type should be used when mask had been generated by an algorithm like ‘SAM’.
mask_url: StringThe URL of the binary mask image that represents the area that will be cleaned./// The URL of the binary mask image that represents the area that will be cleaned./// “https://storage.googleapis.com/falserverless/bria/bria_eraser_mask.png”
preserve_alpha: Option<bool>If set to true, attempts to preserve the alpha channel of the input image.
sync_mode: Option<bool>If set to true, the function will wait for the image to be generated and uploaded before returning the response. This will increase the latency of the function but it allows you to get the image directly in the response without going through the CDN.