pub struct FluxProUltraTextToImageFinetunedInput {
pub aspect_ratio: Option<AspectRatioProperty>,
pub enable_safety_checker: Option<bool>,
pub finetune_id: String,
pub finetune_strength: f64,
pub num_images: Option<i64>,
pub output_format: Option<String>,
pub prompt: String,
pub raw: Option<bool>,
pub safety_tolerance: Option<String>,
pub seed: Option<i64>,
pub sync_mode: Option<bool>,
}Fields
aspect_ratio: Option<AspectRatioProperty>The aspect ratio of the generated image.
enable_safety_checker: Option<bool>If set to true, the safety checker will be enabled.
finetune_id: StringReferences your specific model
finetune_strength: f64Controls finetune influence. Increase this value if your target concept isn’t showing up strongly enough. The optimal setting depends on your finetune and prompt
num_images: Option<i64>The number of images to generate.
output_format: Option<String>The format of the generated image.
prompt: StringThe prompt to generate an image from./// The prompt to generate an image from./// “Extreme close-up of a single tiger eye, direct frontal view. Detailed iris and pupil. Sharp focus on eye texture and color. Natural lighting to capture authentic eye shine and depth. The word "FLUX" is painted over it in big, white brush strokes with visible texture.”
raw: Option<bool>Generate less processed, more natural-looking images.
safety_tolerance: Option<String>The safety tolerance level for the generated image. 1 being the most strict and 5 being the most permissive.
seed: Option<i64>The same seed and the same prompt given to the same version of the model will output the same image every time.
sync_mode: Option<bool>If set to true, the function will wait for the image to be generated and uploaded before returning the response. This will increase the latency of the function but it allows you to get the image directly in the response without going through the CDN.