pub struct ImageToImageSD15Input {Show 15 fields
pub embeddings: Option<Vec<Option<Embedding>>>,
pub enable_safety_checker: Option<bool>,
pub expand_prompt: Option<bool>,
pub format: Option<String>,
pub guidance_scale: Option<f64>,
pub image_size: Option<ImageSizeProperty>,
pub image_url: String,
pub loras: Option<Vec<Option<LoraWeight>>>,
pub negative_prompt: Option<String>,
pub num_images: Option<i64>,
pub num_inference_steps: Option<i64>,
pub prompt: String,
pub seed: Option<i64>,
pub strength: Option<f64>,
pub sync_mode: Option<bool>,
}Fields
embeddings: Option<Vec<Option<Embedding>>>The list of embeddings to use.
enable_safety_checker: Option<bool>If set to true, the safety checker will be enabled.
expand_prompt: Option<bool>If set to true, the prompt will be expanded with additional prompts.
format: Option<String>The format of the generated image.
guidance_scale: Option<f64>The CFG (Classifier Free Guidance) scale is a measure of how close you want the model to stick to your prompt when looking for a related image to show you.
image_size: Option<ImageSizeProperty>The size of the generated image.
image_url: StringThe URL of the image to use as a starting point for the generation./// The URL of the image to use as a starting point for the generation./// “https://fal-cdn.batuhan-941.workers.dev/files/tiger/IExuP-WICqaIesLZAZPur.jpeg”
loras: Option<Vec<Option<LoraWeight>>>The list of LoRA weights to use.
negative_prompt: Option<String>The negative prompt to use.Use it to address details that you don’t want in the image. This could be colors, objects, scenery and even the small details (e.g. moustache, blurry, low resolution)./// The negative prompt to use.Use it to address details that you don’t want in the image. This could be colors, objects, scenery and even the small details (e.g. moustache, blurry, low resolution)./// “cartoon, illustration, animation. face. male, female”
num_images: Option<i64>The number of images to generate.
num_inference_steps: Option<i64>The number of inference steps to perform.
prompt: StringThe prompt to use for generating the image. Be as descriptive as possible for best results./// The prompt to use for generating the image. Be as descriptive as possible for best results./// “an island near sea, with seagulls, moon shining over the sea, light house, boats int he background, fish flying over the sea”
seed: Option<i64>The same seed and the same prompt given to the same version of Stable Diffusion will output the same image every time.
strength: Option<f64>determines how much the generated image resembles the initial image
sync_mode: Option<bool>If set to true, the function will wait for the image to be generated and uploaded before returning the response. This will increase the latency of the function but it allows you to get the image directly in the response without going through the CDN.